@@ -18,6 +18,9 @@ macro_rules! pubkey {
     };
 }
 
+#[macro_use]
+extern crate const_format;
+
 extern crate serde_derive;
 
 pub mod checks;
